SpecificUnitConversion class
data.
For example, using Unit.byte, given a file 3 MB large, the file size will be given as 3,000,000 bytes.
- Inheritance
-
- Object
- UnitConversion
- SpecificUnitConversion
Constructors
- SpecificUnitConversion({required Unit unit})
-
Returns an instance of SpecificUnitConversion.
const
Properties
Methods
-
bitsToUnit(
{required BigInt bits}) → Unit -
Given a size in
bits, returns a Unit to represent itoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited